@@ -21,17 +21,16 @@
 #include "config.h"
 #endif
 
-#include "libxfce4panel/xfce-panel-convenience.h"
-#include "libxfce4panel/xfce-panel-macros.h"
+#include "xfce-panel-convenience.h"
+#include "xfce-panel-macros.h"
+#include "libxfce4panel-alias.h"
 
-#include "libxfce4panel/libxfce4panel-alias.h"
+#include <libxfce4util/libxfce4util.h>
 
 #ifdef HAVE_MATH_H
 #include <math.h>
 #endif
 
-#include <libxfce4util/libxfce4util.h>
-
 
 
 /**
@@ -356,4 +355,4 @@ xfce_panel_set_image_from_source (GtkImage *image,
 
 
 #define __XFCE_PANEL_CONVENIENCE_C__
-#include "libxfce4panel/libxfce4panel-aliasdef.c"
+#include "libxfce4panel-aliasdef.c"
