@@ -21,14 +21,18 @@
 #include "config.h"
 #endif
 
-#include "panel/panel-itembar.h"
-#include "panel/panel-window.h"
+#include "panel-itembar.h"
+#include "panel-window.h"
 
 #include "common/panel-debug.h"
 #include "common/panel-private.h"
 #include "libxfce4panel/libxfce4panel.h"
 #include "libxfce4panel/xfce-panel-plugin-provider.h"
 
+#ifdef HAVE_MATH_H
+#include <math.h>
+#endif
+
 #define IS_HORIZONTAL(itembar) ((itembar)->mode == XFCE_PANEL_PLUGIN_MODE_HORIZONTAL)
 #define HIGHLIGHT_SIZE 2
 
