@@ -27,8 +27,11 @@
 #include "common/panel-debug.h"
 #include "common/panel-private.h"
 
+#ifdef HAVE_MATH_H
+#include <math.h>
+#endif
+
 #define SPACING (2)
-#define OFFSCREEN (-9999)
 
 /* some icon implementations request a 1x1 size for invisible icons */
 #define REQUISITION_IS_INVISIBLE(child_req) ((child_req).width <= 1 && (child_req).height <= 1)
